@@ -118,7 +118,7 @@ class JSONAPIResponse(object):
         self.status_code = 200
         self.data = {
             'jsonapi': {'version': '1.0'},
-            'meta': {'sqlalchemy_jsonapi_version': '2.0.0'}
+            'meta': {'sqlalchemy_jsonapi_version': '2.0.3'}
         }
 
 
@@ -366,7 +366,7 @@ class JSONAPI(object):
                     if key in local_fields:
                         to_ret['relationships'][key]['data'].append({
                             'id': item.id,
-                            'type': api_type
+                            'type': item.__jsonapi_type__
                         })
 
                     if key in include.keys():
